Index: src/arm/code-stubs-arm.cc |
diff --git a/src/arm/code-stubs-arm.cc b/src/arm/code-stubs-arm.cc |
index 8466346a9de18da30dd73de22a49f2aa92f1e642..5f2f68d0fbcff5351e62939e326f9994fd8f4df1 100644 |
--- a/src/arm/code-stubs-arm.cc |
+++ b/src/arm/code-stubs-arm.cc |
@@ -106,10 +106,10 @@ void FastNewClosureStub::Generate(MacroAssembler* masm) { |
? Context::FUNCTION_MAP_INDEX |
: Context::STRICT_MODE_FUNCTION_MAP_INDEX; |
// Compute the function map in the current global context and set that |
// as the map of the allocated object. |
__ ldr(r2, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
- __ ldr(r2, FieldMemOperand(r2, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r2, FieldMemOperand(r2, GlobalObject::kNativeContextOffset)); |
__ ldr(r5, MemOperand(r2, Context::SlotOffset(map_index))); |
__ str(r5, FieldMemOperand(r0, HeapObject::kMapOffset)); |
@@ -149,8 +149,8 @@ void FastNewClosureStub::Generate(MacroAssembler* masm) { |
__ IncrementCounter(counters->fast_new_closure_try_optimized(), 1, r6, r7); |
// r2 holds global context, r1 points to fixed array of 3-element entries |
// (global context, optimized code, literals). |
// The optimized code map must never be empty, so check the first elements. |
Label install_optimized; |
// Speculatively move code object into r4. |
@@ -290,9 +290,9 @@ void FastNewBlockContextStub::Generate(MacroAssembler* masm) { |
__ mov(r2, Operand(Smi::FromInt(length))); |
__ str(r2, FieldMemOperand(r0, FixedArray::kLengthOffset)); |
// If this block context is nested in the global context we get a smi |
// sentinel instead of a function. The block context should get the |
// canonical empty function of the global context as its closure which |
// we still have to look up. |
Label after_sentinel; |
__ JumpIfNotSmi(r3, &after_sentinel); |
@@ -302,7 +302,7 @@ void FastNewBlockContextStub::Generate(MacroAssembler* masm) { |
__ Assert(eq, message); |
} |
__ ldr(r3, GlobalObjectOperand()); |
- __ ldr(r3, FieldMemOperand(r3, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r3, FieldMemOperand(r3, GlobalObject::kNativeContextOffset)); |
__ ldr(r3, ContextOperand(r3, Context::CLOSURE_INDEX)); |
__ bind(&after_sentinel); |
@@ -4514,7 +4514,7 @@ void ArgumentsAccessStub::GenerateNewNonStrictFast(MacroAssembler* masm) { |
Context::SlotOffset(Context::ALIASED_ARGUMENTS_BOILERPLATE_INDEX); |
__ ldr(r4, MemOperand(r8, Context::SlotOffset(Context::GLOBAL_INDEX))); |
- __ ldr(r4, FieldMemOperand(r4, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r4, FieldMemOperand(r4, GlobalObject::kNativeContextOffset)); |
__ cmp(r1, Operand::Zero()); |
__ ldr(r4, MemOperand(r4, kNormalOffset), eq); |
__ ldr(r4, MemOperand(r4, kAliasedOffset), ne); |
@@ -4689,7 +4689,7 @@ void ArgumentsAccessStub::GenerateNewStrict(MacroAssembler* masm) { |
// Get the arguments boilerplate from the current (global) context. |
__ ldr(r4, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
- __ ldr(r4, FieldMemOperand(r4, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r4, FieldMemOperand(r4, GlobalObject::kNativeContextOffset)); |
__ ldr(r4, MemOperand(r4, Context::SlotOffset( |
Context::STRICT_MODE_ARGUMENTS_BOILERPLATE_INDEX))); |
@@ -5207,7 +5207,7 @@ void RegExpConstructResultStub::Generate(MacroAssembler* masm) { |
__ ldr(r2, ContextOperand(cp, Context::GLOBAL_INDEX)); |
__ add(r3, r0, Operand(JSRegExpResult::kSize)); |
__ mov(r4, Operand(factory->empty_fixed_array())); |
- __ ldr(r2, FieldMemOperand(r2, GlobalObject::kGlobalContextOffset)); |
+ __ ldr(r2, FieldMemOperand(r2, GlobalObject::kNativeContextOffset)); |
__ str(r3, FieldMemOperand(r0, JSObject::kElementsOffset)); |
__ ldr(r2, ContextOperand(r2, Context::REGEXP_RESULT_MAP_INDEX)); |
__ str(r4, FieldMemOperand(r0, JSObject::kPropertiesOffset)); |
@@ -106,10 +106,10 @@ void FastNewClosureStub::Generate(MacroAssembler* masm) { |
? Context::FUNCTION_MAP_INDEX |
: Context::STRICT_MODE_FUNCTION_MAP_INDEX; |
- // Compute the function map in the current global context and set that |
+ // Compute the function map in the current native context and set that |
// as the map of the allocated object. |
__ ldr(r2, MemOperand(cp, Context::SlotOffset(Context::GLOBAL_INDEX))); |
@@ -149,8 +149,8 @@ void FastNewClosureStub::Generate(MacroAssembler* masm) { |
__ IncrementCounter(counters->fast_new_closure_try_optimized(), 1, r6, r7); |
- // r2 holds global context, r1 points to fixed array of 3-element entries |
- // (global context, optimized code, literals). |
+ // r2 holds native context, r1 points to fixed array of 3-element entries |
+ // (native context, optimized code, literals). |
// The optimized code map must never be empty, so check the first elements. |
Label install_optimized; |
@@ -290,9 +290,9 @@ void FastNewBlockContextStub::Generate(MacroAssembler* masm) { |
__ mov(r2, Operand(Smi::FromInt(length))); |
__ str(r2, FieldMemOperand(r0, FixedArray::kLengthOffset)); |
- // If this block context is nested in the global context we get a smi |
+ // If this block context is nested in the native context we get a smi |
// sentinel instead of a function. The block context should get the |
@@ -290,9 +290,9 @@ void FastNewBlockContextStub::Generate(MacroAssembler* masm) { |
// sentinel instead of a function. The block context should get the |
- // canonical empty function of the global context as its closure which |
+ // canonical empty function of the native context as its closure which |
// we still have to look up. |
Label after_sentinel; |